@@ -86,7 +86,7 @@ impl PodSpecExt for corev1::PodSpec {
     }
 
     fn volumes(self, volumes: impl IntoIterator<Item = corev1::Volume>) -> Self {
-        let volumes = Some(Vec::from_iter(volumes));
+        let volumes = Some(volumes.into_iter().collect());
         Self { volumes, ..self }
     }
 }
