@@ -1,9 +1,17 @@
 use anyhow::Context;
 use k8s_cluster_api::v1beta1 as capiv1;
+use kube::config;
 
 use super::*;
 
 impl Kubectl {
+    pub async fn load_config_from_secret(&self, cluster: &str) -> kube::Result<kube::Config> {
+        let text = self.capi_kubeconfig(cluster).await?;
+        load_config_from_text(&text)
+            .await
+            .map_err(from_kubeconfig_error)
+    }
+
     pub async fn capi_kubeconfig(&self, cluster: &str) -> kube::Result<String> {
         let secret = format!("{}-kubeconfig", cluster);
         self.load_text_from_secret(&secret, "value").await
@@ -68,3 +76,24 @@ impl Kubectl {
         Ok(control_plane)
     }
 }
+
+async fn load_config_from_text(text: &str) -> Result<config::Config, config::KubeconfigError> {
+    let kubeconfig = config::Kubeconfig::from_yaml(text)?;
+    let options = config::KubeConfigOptions::default();
+    config::Config::from_custom_kubeconfig(kubeconfig, &options).await
+}
+
+fn from_kubeconfig_error(err: config::KubeconfigError) -> kube::Error {
+    // This is a workaround until the real error code will be possible to create
+    // let infer = config::InferConfigError {
+    //     in_cluster: config::InClusterError::MissingEnvironmentVariables, // Dummy error
+    //     kubeconfig: err,
+    // };
+    // kube::Error::InferConfig(infer)
+    log::warn!(
+        "Replacing {} with Error::LinesCodecMaxLineLengthExceeded",
+        err
+    );
+
+    kube::Error::LinesCodecMaxLineLengthExceeded
+}
