@@ -1,14 +1,14 @@
 //
-// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
+// Copyright (c) 2022 RepliXio Ltd. All rights reserved.
 // Use is subject to license terms.
 //
 
-use std::time::Duration;
-
 use serde_json as json;
+use tokio::time;
+
+use crate::ResourceExt as _;
 
 use super::*;
-use crate::ext::ResourceExt as _;
 
 impl super::Kubectl {
     pub fn delete_params(&self) -> api::DeleteParams {
@@ -231,7 +231,7 @@ impl super::Kubectl {
         client: kube::api::Api<K>,
         name: &str,
         update_fn: impl FnMut(&mut K),
-    ) -> kube::Result<()>
+    ) -> kube::Result<K>
     where
         K: std::fmt::Debug
             + Clone
@@ -254,7 +254,7 @@ impl super::Kubectl {
         name: &str,
         update_fn: impl FnMut(&mut K),
         default: impl Fn() -> K,
-    ) -> kube::Result<()>
+    ) -> kube::Result<K>
     where
         K: std::fmt::Debug
             + Clone
@@ -264,6 +264,7 @@ impl super::Kubectl {
     {
         Self::entry(client, name, Self::MAX_RETRIES, update_fn, Some(default)).await
     }
+
     /// try to `commit` changes (`update_fn`)
     /// to object `K`
     /// of name: `name`
@@ -276,7 +277,7 @@ impl super::Kubectl {
         max_retries: u8,
         mut update_fn: impl FnMut(&mut K),
         default: Option<impl Fn() -> K>,
-    ) -> kube::Result<()>
+    ) -> kube::Result<K>
     where
         K: std::fmt::Debug
             + Clone
@@ -311,11 +312,12 @@ impl super::Kubectl {
                     entry.insert(default())
                 }
             };
+            let mut entry = entry.and_modify(&mut update_fn);
 
-            let e = match entry.and_modify(&mut update_fn).commit().await {
+            let e = match entry.commit().await {
                 Err(CommitError::Save(kube::Error::Api(e))) if e.code == CONFLICT.as_u16() => e,
                 // return for all other case
-                Ok(()) => return Ok(()),
+                Ok(()) => return Ok(entry.into_object()),
                 Err(CommitError::Save(e)) => return Err(e),
                 Err(ref err @ CommitError::Validate(ref e)) => {
                     return Err(kube::Error::Api(ErrorResponse {
@@ -331,10 +333,10 @@ impl super::Kubectl {
             let millis = 1u64
                 .checked_shl(retry_count as u32)
                 .and_then(|pow2| pow2.checked_mul(10))
-                .filter(|&millis| millis < MAX_BACKOFF_MILLI)
+                .filter(|millis| *millis < MAX_BACKOFF_MILLI)
                 .unwrap_or(MAX_BACKOFF_MILLI);
 
-            tokio::time::sleep(Duration::from_millis(millis)).await
+            time::sleep(time::Duration::from_millis(millis)).await
         }
 
         let e = last_err.unwrap_or_else(|| kube::error::ErrorResponse {
@@ -350,7 +352,7 @@ impl super::Kubectl {
         &self,
         name: &str,
         mut update_fn: impl FnMut(&mut BTreeMap<String, String>),
-    ) -> kube::Result<()> {
+    ) -> kube::Result<corev1::ConfigMap> {
         Self::update_with_default(
             self.configmaps(None),
             name,
